/*
 * Copyright (C) Sapphirecode - All Rights Reserved
 * This file is part of encoding-helper which is released under MIT.
 * See file 'LICENSE' for full license details.
 * Created by Timo Hocker <timo@scode.ovh>, May 2020
 */

// @ts-nocheck
/* eslint-disable no-magic-numbers */
'use strict';

const test = require ('ava');
const encoding = require ('../index');


test ('encoding to_hex', (t) => {
  const hex = encoding.to_hex ('foo');
  t.is (hex, '666f6f');
});

test ('encoding to_b64', (t) => {
  const hex = encoding.to_b64 ('foo');
  t.is (hex, 'Zm9v');
});

test ('encoding to_utf8', (t) => {
  const utf = encoding.to_utf8 ('Zm9v', 'base64');
  t.is (utf, 'foo');
});

test ('convert num to hex', (t) => {
  const res = encoding.num_to_hex (11);
  t.is (res, 'b');
});

test ('convert num to hex padded', (t) => {
  const res = encoding.num_to_hex (11, 2);
  t.is (res, '0b');
});

test ('convert hex to num', (t) => {
  const res = encoding.hex_to_num ('b');
  t.is (res, 11);
});

test ('convert hex padded to num', (t) => {
  const res = encoding.hex_to_num ('0b');
  t.is (res, 11);
});
